# the package is arch-dependent because scripts contain arch dependent paths
# the debuginfo package will be empty if produced
%global debug_package %{nil}

Name:       dbus-java
Version:    2.7
Release:    %mkrel 22
Summary:    Java implementation of the DBus protocol
Group:      Development/Java
License:    AFL or LGPLv2
URL:        http://freedesktop.org/wiki/Software/DBusBindings
#URL2:      http://dbus.freedesktop.org/doc/dbus-java/
Source0:    http://dbus.freedesktop.org/releases/%{name}/%{name}-%{version}.tar.gz

# OSGi manifests
Source1:    %{name}-osgi-MANIFEST.MF

# API reference used for documentation
Source2:    http://java.sun.com/j2se/1.5.0/docs/api/package_list#/j2se-1.5.0-api-package_list

Patch1:     classpath_fix.patch
# fedora specific paths
Patch2:     parallel.patch
# java-7 compatibility patch
# https://bugs.freedesktop.org/show_bug.cgi?id=44791
Patch3:     utf-8-encoding.patch
Patch4:     version-less-jars.patch
# Java 9 compatibility patch (openSUSE)
Patch5:     gettext-java-9.patch
# Use prefetched API documentation (avoids fatal error on build system with no net access)
Patch6:     javadoc-linkoffline.patch

BuildRequires:  javapackages-local
BuildRequires:  docbook-utils
BuildRequires:  gettext
BuildRequires:  libmatthew-java
BuildRequires:  docbook2x
BuildRequires:  texlive
BuildRequires:  texlive-texmf

Requires:   java >= 1:1.6.0
Requires:   javapackages-tools
Requires:   libmatthew-java

%description
D-Bus is a message bus system, a simple way for applications to
talk to one another. In addition to interprocess communication,
D-Bus helps coordinate process lifecycle; it makes it simple and
reliable to code a "single instance" application or daemon, and to
launch applications and daemons on demand when their services are
needed.

This is a complete independent implementation of the D-Bus protocol
in Java. It comprises a library to write programs in Java which
access D-Bus, a tool for generating stubs from D-Bus introspection
data and a simple daemon. Being written in Java it works on both
Windows and Linux (and other Unix-like systems).

When using a TCP transport it is entirely Java-based; when using
Unix-sockets it requires a small JNI library to use Unix-Sockets.

%package javadoc
Summary:    Javadocs for %{name}


%description javadoc
Javadocs for %{name}.

%prep
%setup -q
%autopatch -p1

mkdir j2se-1.5.0-api
cp %{SOURCE2} j2se-1.5.0-api/package-list

sed -i "s|!doctype|!DOCTYPE|g" *.sgml
sed -i 's|<!DOCTYPE refentry PUBLIC "-//OASIS//DTD DocBook V4.1//EN"|<!DOCTYPE refentry PUBLIC "-//OASIS//DTD DocBook V4.1//EN" "http://www.oasis-open.org/docbook/xml/4.1.2/docbookx.dtd"|g' *.sgml

%build
# no configure file
%make_build %{?_smp_mflags} \
    DOCBOOKTOMAN="docbook2x-man --to-stdout"\
    -j1 \
    JARPREFIX=%{_javadir}/%{name} \
    BINPREFIX=%{_bindir} \
    MANPREFIX=%{_mandir}/man1 \
    DOCPREFIX=%{_defaultdocdir}/%{name} \
    JAVADOCPREFIX=%{_javadocdir}/%{name} \
    JAVAUNIXLIBDIR=%{_libdir}/libmatthew-java \
    JAVAUNIXJARDIR=%{_jnidir} \
    JAVADOC="javadoc -Xdoclint:none"

# Inject OSGi manifests
jar umf %{SOURCE1} libdbus-java-%{version}.jar

%check
%__make check \
    JARPREFIX=%{_javadir}/%{name} \
    BINPREFIX=%{_bindir} \
    MANPREFIX=%{_mandir}/man1 \
    DOCPREFIX=%{_defaultdocdir}/%{name} \
    JAVADOCPREFIX=%{_javadocdir}/%{name} \
    JAVAUNIXLIBDIR=%{_libdir}/libmatthew-java \
    JAVAUNIXJARDIR=%{_jnidir} \
    JAVADOC="javadoc -Xdoclint:none"


%install
make install \
    DESTDIR=$RPM_BUILD_ROOT \
    JARPREFIX=%{_javadir}/%{name} \
    BINPREFIX=%{_bindir} \
    MANPREFIX=%{_mandir}/man1 \
    DOCPREFIX=%{_defaultdocdir}/%{name} \
    JAVADOCPREFIX=%{_javadocdir}/%{name} \
    JAVAUNIXLIBDIR=%{_libdir}/libmatthew-java \
    JAVAUNIXJARDIR=%{_jnidir} \
    JAVADOC="javadoc -Xdoclint:none"

%files
%{_javadir}/%{name}
%{_bindir}/CreateInterface
%{_bindir}/DBusCall
%{_bindir}/DBusDaemon
%{_bindir}/DBusViewer
%{_bindir}/ListDBus
%doc %{_defaultdocdir}/%{name}
%doc %{_mandir}/man1/CreateInterface.1.*
%doc %{_mandir}/man1/DBusCall.1.*
%doc %{_mandir}/man1/DBusDaemon.1.*
%doc %{_mandir}/man1/DBusViewer.1.*
%doc %{_mandir}/man1/ListDBus.1.*
%doc AUTHORS README
%license COPYING

%files javadoc
%{_javadocdir}/%{name}
%license COPYING


%changelog
* Thu Aug 27 2020 martinw <martinw> 2.7-22.mga8
+ Revision: 1619250
- fix build with JDK 11

* Thu Feb 13 2020 umeabot <umeabot> 2.7-21.mga8
+ Revision: 1511819
- Mageia 8 Mass Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 2.7-20.mga7
+ Revision: 1297414
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Fri Oct 06 2017 daviddavid <daviddavid> 2.7-18.mga7
+ Revision: 1169315
- Add BR on javapackages-local for OSGi metadata detection

* Wed Mar 02 2016 neoclust <neoclust> 2.7-16.mga6
+ Revision: 981958
- Second rebuild of the java stack

* Tue Mar 01 2016 daviddavid <daviddavid> 2.7-15.mga6
+ Revision: 981481
- First rebuild of the java stack
- sync package dbus-java with fedora
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2.7-14.mga5
+ Revision: 745317
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.7-13.mga5
+ Revision: 678686
- Mageia 5 Mass Rebuild

* Tue Jan 07 2014 dmorgan <dmorgan> 2.7-12.mga4
+ Revision: 565388
- Adapt to jnidir changes

* Tue Oct 22 2013 umeabot <umeabot> 2.7-11.mga4
+ Revision: 545838
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 luigiwalser <luigiwalser> 2.7-10.mga4
+ Revision: 501901
- BR texlive-texmf

* Mon Mar 25 2013 zezinho <zezinho> 2.7-9.mga3
+ Revision: 405195
- fix rpm group
+ dmorgan <dmorgan>
- imported package dbus-java


* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Aug 25 2011 Alexander Kurtakov <akurtako@redhat.com> 2.7-7
- Adapt for building/running with openjdk 7.
- Remove not needed parts.

* Sun Feb 13 2011 Mat Booth <fedora@matbooth.co.uk> 2.7-6
- Inject OSGi manifests into jars so that they may be used in OSGi apps such
  as Eclipse plug-ins.

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.7-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jul 8 2010 Omair Majid <omajid@redhat.com> 2.7-4
- Add missing docs to main package and license to javadoc subpackage

* Fri Jan 15 2010 Alexander Kurtakov <akurtako@redhat.com> 2.7-3
- Add docbook2X dependency.

* Fri Jan 15 2010 Alexander Kurtakov <akurtako@redhat.com> 2.7-2
- Fix manpages generation.

* Wed Jan 13 2010 Alexander Kurtakov <akurtako@redhat.com> 2.7-1
- Update to upstream 2.7.
- Drop gcj_support.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Mar 17 2009 Omair Majid <omajid@redhat.com> - 2.5.1-1
- update to 2.5.1
- Added patches from François Kooman <fkooman@tuxed.net>
- Added docs.patch (already upstream). Replaces docbook.patch and 
  man_fixes.patch
- Add missing TestSignalInterface2 interface (already upstream)

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Jul 7 2008 Omair Majid <omajid@redhat.com> - 2.5-3
- Added a patch to fix the htlatex environment
- added -j1 to make to fix the race condition in makefile

* Mon Jun 30 2008 Omair Majid <omajid@redhat.com> - 2.5-2
- fixed incoherent name warning from rpmlint
- fixed wrapper script paths
- added check section

* Wed Jun 25 2008 Omair Majid <omajid@redhat.com> - 2.5-1
- Initial build
